@@ -191,7 +191,8 @@ class IColaboFlowHostData():
 	"""
 	finalizedTaskInstancesInfos: dict[str, IColaboFlowGoTaskInstanceInfo]
 
-	def __init__(self, reportsConfig, hostName, appNameText, appNameTextWithContext, amqpUrl, queueHost, queueHostHeartbeat, queueServiceOrchestrator, listenForOrchestratorRequests = True, processOrchestratorTaskExecuteRequests = True):
+	def __init__(self, reportsConfig, hostName, appNameText, appNameTextWithContext, amqpUrl, queueHost, queueHostHeartbeat, queueServiceOrchestrator, listenForOrchestratorRequests = True, processOrchestratorTaskExecuteRequests = True,
+	concurrency_TasksNo=1):
 		self.reportsConfig = reportsConfig
 		self.hostName = hostName
 		self.appNameText = appNameText
@@ -202,6 +203,7 @@ class IColaboFlowHostData():
 		self.queueServiceOrchestrator = queueServiceOrchestrator
 		self.listenForOrchestratorRequests = listenForOrchestratorRequests
 		self.processOrchestratorTaskExecuteRequests = processOrchestratorTaskExecuteRequests
+		self.concurrency_TasksNo = concurrency_TasksNo
 
 """
 Contains all the data that are necessary for a ColaboFlow.Go client to operate
